@@ -11,11 +11,16 @@ from django.core.exceptions import PermissionDenied
 from django.template.response import TemplateResponse
 from django.utils.encoding import force_text
 from django.utils.html import conditional_escape, format_html
-from django.utils.six import text_type
 from django.utils.translation import ugettext_lazy as _
 
 from .utils import related_objects
 
+# Django 3.0 compatibility
+try:
+    from django.utils.six import text_type
+except ImportError:
+    text_type = str
+
 
 def highlight_deleted(obj):
     """
@@ -88,6 +93,7 @@ class SafeDeleteAdmin(admin.ModelAdmin):
 
     def undelete_selected(self, request, queryset):
         """ Admin action to undelete objects in bulk with confirmation. """
+        original_queryset = queryset.all()
         if not self.has_delete_permission(request):
             raise PermissionDenied
         assert hasattr(queryset, 'undelete')
@@ -96,24 +102,30 @@ class SafeDeleteAdmin(admin.ModelAdmin):
         queryset = queryset.filter(deleted__isnull=False)
         # Undeletion confirmed
         if request.POST.get('post'):
-            n = queryset.count()
-            if n:
+            requested = queryset.count()
+            if requested:
                 for obj in queryset:
                     obj_display = force_text(obj)
                     self.log_undeletion(request, obj, obj_display)
                 queryset.undelete()
-                if django.VERSION[1] <= 4:
+                changed = original_queryset.filter(deleted__isnull=True).count()
+                if changed < requested:
                     self.message_user(
                         request,
-                        _("Successfully undeleted %(count)d %(items)s.") % {
-                            "count": n, "items": model_ngettext(self.opts, n)
+                        _("Successfully undeleted %(count_changed)d of the "
+                          "%(count_requested)d selected %(items)s.") % {
+                            "count_requested": requested,
+                            "count_changed": changed,
+                            "items": model_ngettext(self.opts, requested)
                         },
+                        messages.WARNING,
                     )
                 else:
                     self.message_user(
                         request,
                         _("Successfully undeleted %(count)d %(items)s.") % {
-                            "count": n, "items": model_ngettext(self.opts, n)
+                            "count": requested,
+                            "items": model_ngettext(self.opts, requested)
                         },
                         messages.SUCCESS,
                     )
