@@ -1,19 +1,9 @@
 import itertools
 
-from django.contrib.admin.util import NestedObjects
+from django.contrib.admin.utils import NestedObjects
 from django.db import router
 
 
-HARD_DELETE, SOFT_DELETE, SOFT_DELETE_CASCADE, HARD_DELETE_NOCASCADE = range(4)
-
-DELETED_INVISIBLE, DELETED_VISIBLE_BY_PK = range(10, 12)
-
-
-# FIXME: Normally we must be able to use the django Collector, not the NestedObject
-#        of the admin.
-#        but the django collector returns only the objects we give it, nothing more.
-#        Bug ?
-
 def related_objects(obj):
     """ Return a generator to the objects that would be deleted if we delete "obj" (excluding obj) """
 
@@ -28,3 +18,7 @@ def related_objects(obj):
         return ()
 
     return flatten(collector.nested())
+
+
+def can_hard_delete(obj):
+    return not bool(list(related_objects(obj)))
